DelegationWalletIdentifier class

Identifies a wallet for delegation operations by chain and address.

Constructors

DelegationWalletIdentifier({required ChainEnum chainName, required String accountAddress})
DelegationWalletIdentifier.fromJson(Map<String, dynamic> json)
factory

Properties

accountAddress String
The wallet account address.
final
chainName ChainEnum
The blockchain chain (e.g., ChainEnum.evm, ChainEnum.sol).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited