MfaAddDevice constructor

const MfaAddDevice({
  1. required String id,
  2. required String secret,
  3. required String uri,
})

Creates a new MfaAddDevice instance.

id is the unique identifier of the newly created MFA device. secret is the secret key used for generating TOTP codes (for TOTP devices). uri is the URI that can be used to generate a QR code for easy setup in authenticator apps (for TOTP devices).

Implementation

const factory MfaAddDevice({
  required String id,
  required String secret,
  required String uri,
}) = _MfaAddDeviceParams;