MultichainBalancesResponse class

Response model for multichain balances.

Constructors

MultichainBalancesResponse({required List<TokenBalance> balances})
MultichainBalancesResponse.fromJson(dynamic json)
factory

Properties

balances List<TokenBalance>
List of token balances across chains.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited