ProviderEnum enum

Inheritance
Available extensions

Values

alchemy → const ProviderEnum
apple → const ProviderEnum
banxa → const ProviderEnum
bitbucket → const ProviderEnum
blocto → const ProviderEnum
coinbasesocial → const ProviderEnum
coinbaseWaas → const ProviderEnum
discord → const ProviderEnum
dynamic → const ProviderEnum
emailOnly → const ProviderEnum
facebook → const ProviderEnum
farcaster → const ProviderEnum
github → const ProviderEnum
gitlab → const ProviderEnum
google → const ProviderEnum
instagram → const ProviderEnum
linkedin → const ProviderEnum
microsoft → const ProviderEnum
sms → const ProviderEnum
telegram → const ProviderEnum
turnkey → const ProviderEnum
twitch → const ProviderEnum
twitter → const ProviderEnum
zerodev → const ProviderEnum

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ProviderEnum>
A constant List of the values in this enum, in order of their declaration.