RegisteredDevice class

Annotations
  • @JsonSerializable.new()

Constructors

RegisteredDevice({required String id, required String createdAt, String? displayText, String? type, bool? isCurrentDevice})
RegisteredDevice.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
displayText String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isCurrentDevice bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited