WalletDelegatedStatus class

Represents the delegation status of a single wallet.

Constructors

WalletDelegatedStatus({required String id, required String address, required String chain, required DelegationStatus status, bool? isDismissedThisSession})
WalletDelegatedStatus.fromJson(Map<String, dynamic> json)
factory

Properties

address String
Wallet address.
final
chain String
Chain identifier (e.g., 'EVM', 'SOL').
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the wallet.
final
isDismissedThisSession bool?
Whether the prompt was dismissed for this session.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status DelegationStatus
Current delegation status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited