waas property
WaasModule
get
waas
Returns the WaaS module for password management operations on embedded wallets.
Implementation
WaasModule get waas => _waasModule;
Returns the WaaS module for password management operations on embedded wallets.
WaasModule get waas => _waasModule;