DelegationModule class
Module for managing delegated access to WaaS/embedded wallets.
Provides methods to delegate, revoke, deny, and manage wallet delegation.
Access via WaasModule.delegation:
await DynamicSDK.instance.wallets.waas.delegation.delegateKeyShares(wallets: [...]);
Constructors
- DelegationModule(MessageTransport messageTransport)
- Creates a new DelegationModule instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestChannel ↔ RequestChannel
-
Request channel for sending delegation requests to WebView.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearDelegationSessionState(
) → Future< void> - Clears all session dismissal state for delegation prompts.
- Delegates specific wallets programmatically without UI.
-
denyWalletDelegation(
{required String walletId}) → Future< void> - Permanently denies delegation for a specific wallet.
-
dismissDelegationPrompt(
{String? walletId}) → Future< void> - Dismisses the delegation prompt for the current session.
-
getWalletsDelegatedStatus(
) → Future< List< WalletDelegatedStatus> > - Gets the current delegation status of all wallets.
-
initDelegationProcess(
{List< String> ? walletIds}) → Future<void> - Opens the delegation modal UI.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revokeDelegation(
{required List< DelegationWalletIdentifier> wallets}) → Future<void> - Revokes delegation for specific wallets.
-
shouldPromptWalletDelegation(
) → Future< bool> - Checks if the user should be prompted for wallet delegation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited