shouldPromptWalletDelegation method
Checks if the user should be prompted for wallet delegation.
Returns true if the user should be prompted to delegate wallets.
Implementation
Future<bool> shouldPromptWalletDelegation() {
return requestChannel.request<bool>(
'shouldPromptWalletDelegation',
args: [],
builder: (data) => data as bool,
);
}