PasskeyRegisterResponseData class
Response data for passkey registration.
- Annotations
-
- @freezed
Constructors
-
PasskeyRegisterResponseData({required String clientDataJSON, required String attestationObject, List<
String> ? transports}) -
constfactory
-
PasskeyRegisterResponseData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attestationObject → String
-
no setterinherited
- clientDataJSON → String
-
no setterinherited
-
copyWith
→ $PasskeyRegisterResponseDataCopyWith<
PasskeyRegisterResponseData> -
Create a copy of PasskeyRegisterResponseData
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transports
→ List<
String> ? -
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PasskeyRegisterResponseData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited